@@ -4,13 +4,13 @@ uses_git <- function(path = ".") {
 
 # sha of most recent commit
 git_repo_sha1 <- function(r) {
-  rev <- git2r::head(r)
+  rev <- git2r_head(r)
   if (is.null(rev)) {
     return(NULL)
   }
 
   if (git2r::is_commit(rev)) {
-    rev@sha
+    git2r_attrib(rev, "sha")
   } else {
     git2r::branch_target(rev)
   }
@@ -28,21 +28,21 @@ git_uncommitted <- function(path = ".") {
   any(st != 0)
 }
 
-git_sync_status <- function(path = ".") {
+git_sync_status <- function(path = ".", check_ahead = TRUE, check_behind = TRUE) {
   r <- git2r::repository(path, discover = TRUE)
 
-  r_head <- git2r::head(r)
+  r_head <- git2r_head(r)
   if (!methods::is(r_head, "git_branch")) {
-    return(invisible(FALSE))
+    stop("HEAD is not a branch", call. = FALSE)
   }
 
   upstream <- git2r::branch_get_upstream(r_head)
-  # fetch(r, branch_remote_name(upstream))
-
   if (is.null(upstream)) {
-    return(invisible(FALSE))
+    stop("No upstream branch", call. = FALSE)
   }
 
+  git2r::fetch(r, git2r::branch_remote_name(upstream))
+
   c1 <- git2r::lookup(r, git2r::branch_target(r_head))
   c2 <- git2r::lookup(r, git2r::branch_target(upstream))
   ab <- git2r::ahead_behind(c1, c2)
@@ -52,7 +52,10 @@ git_sync_status <- function(path = ".") {
 #   if (ab[2] > 0)
 #     message(ab[2], " behind remote")
 
-  invisible(any(ab != 0))
+  is_ahead <- ab[[1]] != 0
+  is_behind <- ab[[2]] != 0
+  check <- (check_ahead && is_ahead) || (check_behind && is_behind)
+  check
 }
 
 # Retrieve the current running path of the git binary.
@@ -90,7 +93,7 @@ git_branch <- function(path = ".") {
      return(NULL)
   }
 
-  git2r::head(r)@name
+  git2r_attrib(git2r_head(r), "name")
 }
 
 # GitHub ------------------------------------------------------------------
@@ -122,7 +125,7 @@ github_info <- function(path = ".", remote_name = NULL) {
   github_remote_parse(x)
 }
 
-github_dummy <- list(username = "<USERNAME>", repo = "<REPO>")
+github_dummy <- list(username = "<USERNAME>", repo = "<REPO>", fullname = "<USERNAME>/<REPO>")
 
 remote_urls <- function(r) {
   remotes <- git2r::remotes(r)
@@ -135,8 +138,9 @@ github_remote_parse <- function(x) {
 
   if (grepl("^(https|git)", x)) {
     # https://github.com/hadley/devtools.git
+    # https://github.com/hadley/devtools
     # git@github.com:hadley/devtools.git
-    re <- "github[^/:]*[/:](.*?)/(.*)\\.git"
+    re <- "github[^/:]*[/:]([^/]+)/(.*?)(?:\\.git)?$"
   } else {
     stop("Unknown GitHub repo format", call. = FALSE)
   }
