@@ -1,26 +1,5 @@
 context("remote-metadata")
 
-## set-up and tear-down
-create_in_temp <- function(pkg) {
-  temp_path <- tempfile(pattern="devtools-test-")
-  dir.create(temp_path)
-  test_pkg <- file.path(temp_path, pkg)
-  capture.output(suppressMessages(create(test_pkg)))
-  test_pkg
-}
-erase <- function(path) unlink(path, recursive = TRUE)
-
-## fake GitHub connectivity: set a GitHub remote and add GitHub links
-mock_use_github <- function(pkg) {
-  use_git(pkg = pkg)
-  r <- git2r::repository(pkg)
-  git2r::remote_add(r, "origin", "https://github.com/hadley/devtools.git")
-  use_github_links(pkg)
-  git2r::add(r, "DESCRIPTION")
-  git2r::commit(r, "Add GitHub links to DESCRIPTION")
-  invisible(NULL)
-}
-
 test_that("pkg_sha metadata from shallow clone", {
 
     pkg_sha <- git_sha1(path='shallowRepo')
@@ -60,7 +39,7 @@ test_that("install on packages adds metadata", {
     library("testMetadataInstall")
     pkg_info <- session_info()$packages
     pkg_source <- pkg_info[pkg_info[, "package"] %in% "testMetadataInstall", "source"]
-    pkg_sha <- substring(git2r::commits(r)[[1]]@sha, 1, 7)
+    pkg_sha <- substring(git2r_attrib(git2r::commits(r)[[1]], "sha"), 1, 7)
     expect_match(pkg_source, pkg_sha)
 
     # dirty the repo
@@ -77,7 +56,7 @@ test_that("install on packages adds metadata", {
     install(test_pkg, quiet = TRUE)
     pkg_info <- session_info()$packages
     pkg_source <- pkg_info[pkg_info[, "package"] %in% "testMetadataInstall", "source"]
-    pkg_sha <- substring(git2r::commits(r)[[1]]@sha, 1, 7)
+    pkg_sha <- substring(git2r_attrib(git2r::commits(r)[[1]], "sha"), 1, 7)
     expect_match(pkg_source, pkg_sha)
 
   })
